@@ -39,7 +39,7 @@ else:
 
 domain = r'https?://(?:www\.|old\.|pay\.|ssl\.|[a-z]{2}\.)?reddit\.com'
 subreddit_url = r'%s/r/([\w-]+)/?$' % domain
-post_url = r'%s/r/\S+?/comments/([\w-]+)(?:/[\w]+)?/?$' % domain
+post_url = r'%s/r/\S+?/comments/([\w-]+)(?:/[\w%%]+)?/?$' % domain
 short_post_url = r'https?://redd\.it/([\w-]+)'
 user_url = r'%s/u(?:ser)?/([\w-]+)' % domain
 comment_url = r'%s/r/\S+?/comments/\S+?/\S+?/([\w-]+)' % domain
@@ -73,6 +73,24 @@ def get_time_created(bot, trigger, entrytime):
     return created
 
 
+def get_is_cakeday(entrytime):
+    now = dt.datetime.utcnow()
+    cakeday_start = dt.datetime.utcfromtimestamp(entrytime)
+    cakeday_start = cakeday_start.replace(year=now.year)
+    day = dt.timedelta(days=1)
+    year_div_by_400 = now.year % 400 == 0
+    year_div_by_100 = now.year % 100 == 0
+    year_div_by_4 = now.year % 4 == 0
+    is_leap = year_div_by_400 or ((not year_div_by_100) and year_div_by_4)
+    if (not is_leap) and ((cakeday_start.month, cakeday_start.day) == (2, 29)):
+        # If cake day is 2/29 and it's not a leap year, cake day is 3/1.
+        # Cake day begins at exact account creation time.
+        is_cakeday = cakeday_start + day <= now <= cakeday_start + (2 * day)
+    else:
+        is_cakeday = cakeday_start <= now <= cakeday_start + day
+    return is_cakeday
+
+
 @url(image_url)
 def image_info(bot, trigger, match):
     url = match.group(0)
@@ -86,7 +104,7 @@ def image_info(bot, trigger, match):
     except IndexError:
         # Fail silently if the image link can't be mapped to a submission
         return NOLIMIT
-    return say_post_info(bot, trigger, oldest.id, False)
+    return say_post_info(bot, trigger, oldest.id, False, True)
 
 
 @url(video_url)
@@ -96,7 +114,8 @@ def video_info(bot, trigger, match):
         'https://www.reddit.com/video/{}'.format(match.group(1)),
         timeout=(10.0, 4.0)).headers['Location']
     try:
-        return say_post_info(bot, trigger, re.match(post_url, url).group(1), False)
+        return say_post_info(
+            bot, trigger, re.match(post_url, url).group(1), False, True)
     except AttributeError:
         # Fail silently if we can't map the video link to a submission
         return NOLIMIT
@@ -109,13 +128,13 @@ def rpost_info(bot, trigger, match):
     return say_post_info(bot, trigger, match.group(1))
 
 
-def say_post_info(bot, trigger, id_, show_link=True):
+def say_post_info(bot, trigger, id_, show_link=True, show_comments_link=False):
     try:
         s = bot.memory['reddit_praw'].submission(id=id_)
 
         message = ('[REDDIT] {title} {link}{nsfw} | {points} points ({percent}) | '
                    '{comments} comments | Posted by {author} | '
-                   'Created at {created}')
+                   'Created at {created}{comments_link}')
 
         subreddit = s.subreddit.display_name
         if not show_link:
@@ -161,10 +180,19 @@ def say_post_info(bot, trigger, id_, show_link=True):
 
         percent = color(unicode(s.upvote_ratio * 100) + '%', point_color)
 
+        comments_link = ''
+        if show_comments_link:
+            try:
+                comments_link = ' | ' + s.shortlink
+            except AttributeError:
+                # the value assigned earlier will be used
+                pass
+
         title = unescape(s.title)
         message = message.format(
             title=title, link=link, nsfw=nsfw, points=s.score, percent=percent,
-            comments=s.num_comments, author=author, created=created)
+            comments=s.num_comments, author=author, created=created,
+            comments_link=comments_link)
 
         bot.say(message)
     except prawcore.exceptions.NotFound:
@@ -253,40 +281,31 @@ def redditor_info(bot, trigger, match, commanded=False):
     """Shows information about the given Redditor"""
     try:
         u = bot.memory['reddit_praw'].redditor(match)
-        message = '[REDDITOR] ' + u.name
-        now = dt.datetime.utcnow()
-        cakeday_start = dt.datetime.utcfromtimestamp(u.created_utc)
-        cakeday_start = cakeday_start.replace(year=now.year)
-        day = dt.timedelta(days=1)
-        year_div_by_400 = now.year % 400 == 0
-        year_div_by_100 = now.year % 100 == 0
-        year_div_by_4 = now.year % 4 == 0
-        is_leap = year_div_by_400 or ((not year_div_by_100) and year_div_by_4)
-        if (not is_leap) and ((cakeday_start.month, cakeday_start.day) == (2, 29)):
-            # If cake day is 2/29 and it's not a leap year, cake day is 3/1.
-            # Cake day begins at exact account creation time.
-            is_cakeday = cakeday_start + day <= now <= cakeday_start + (2 * day)
-        else:
-            is_cakeday = cakeday_start <= now <= cakeday_start + day
-
-        if is_cakeday:
-            message = message + ' | ' + bold(color('Cake day', colors.LIGHT_PURPLE))
-        if commanded:
-            message = message + ' | https://reddit.com/u/' + u.name
-        if u.is_gold:
-            message = message + ' | ' + bold(color('Gold', colors.YELLOW))
-        if u.is_mod:
-            message = message + ' | ' + bold(color('Mod', colors.GREEN))
-        message = message + (' | Link: ' + str(u.link_karma) +
-                             ' | Comment: ' + str(u.comment_karma))
-
-        bot.say(message)
+        u.id  # shortcut to check if the user exists or not
     except prawcore.exceptions.NotFound:
         if commanded:
             bot.say('No such Redditor.')
         # Fail silently if it wasn't an explicit command.
         return NOLIMIT
 
+    message = '[REDDITOR] ' + u.name
+    is_cakeday = get_is_cakeday(u.created_utc)
+
+    if is_cakeday:
+        message = message + ' | ' + bold(color('Cake day', colors.LIGHT_PURPLE))
+    if commanded:
+        message = message + ' | https://reddit.com/u/' + u.name
+    if u.is_gold:
+        message = message + ' | ' + bold(color('Gold', colors.YELLOW))
+    if u.is_employee:
+        message = message + ' | ' + bold(color('Employee', colors.RED))
+    if u.is_mod:
+        message = message + ' | ' + bold(color('Mod', colors.GREEN))
+    message = message + (' | Link: ' + str(u.link_karma) +
+                         ' | Comment: ' + str(u.comment_karma))
+
+    bot.say(message)
+
 
 @url(user_url)
 def auto_redditor_info(bot, trigger, match):
